@@ -72,10 +72,11 @@ sql_escape_string (const char *ustr)
   char *str, *q;
   const unsigned char *p;
   size_t len = strlen (ustr);
+#define ESCAPABLE_CHAR "\\'\""
   
   for (p = (const unsigned char *) ustr; *p; p++)
     {
-      if (strchr ("'\"", *p))
+      if (strchr (ESCAPABLE_CHAR, *p))
 	len++;
     }
 
@@ -85,7 +86,7 @@ sql_escape_string (const char *ustr)
 
   for (p = (const unsigned char *) ustr, q = str; *p; p++)
     {
-      if (strchr ("'\"", *p))
+      if (strchr (ESCAPABLE_CHAR, *p))
 	*q++ = '\\';
       *q++ = *p;
     }
@@ -346,7 +347,7 @@ mu_auth_sql_by_name (struct mu_auth_data **return_data,
     }
   else
     {
-      char *mailbox_name;
+      char *mailbox_name = NULL;
       char *name;
       
       mu_sql_get_column (conn, 0, 0, &name);
@@ -359,10 +360,8 @@ mu_auth_sql_by_name (struct mu_auth_data **return_data,
 	}
       else
 	{
-	  mailbox_name = malloc (strlen (mu_path_maildir) +
-				 strlen (name) + 1);
-	  if (mailbox_name)
-	    sprintf (mailbox_name, "%s%s", mu_path_maildir, name);
+	  mu_construct_user_mailbox_url (&mailbox_name, name);
+	  /* FIXME: Error code is lost */
 	}
       
       if (mailbox_name)
@@ -480,7 +479,7 @@ mu_auth_sql_by_uid (struct mu_auth_data **return_data,
   else
     {
       char *name;
-      char *mailbox_name;
+      char *mailbox_name = NULL;
       
       mu_sql_get_column (conn, 0, 0, &name);
   
@@ -492,10 +491,8 @@ mu_auth_sql_by_uid (struct mu_auth_data **return_data,
 	}
       else
 	{
-	  mailbox_name = malloc (strlen (mu_path_maildir) +
-				 strlen (name) + 1);
-	  if (mailbox_name)
-	    sprintf (mailbox_name, "%s%s", mu_path_maildir, name);
+          mu_construct_user_mailbox_url (&mailbox_name, name);      
+          /* FIXME: Error code is lost */
 	}
       
       if (mailbox_name)
